<html>
  <head>
    <title>last-modified-at-with-format</title>
  </head>
  <body>
    <span class="last-modified-at">Article last updated on {% last_modified_at %Y:%B:%A:%d %}</span>

    {{ content }}
  </body>
</html>
